atomate.feff.workflows package — atomate 0.3 documentation

# atomate.feff.workflows package

## Submodules

## atomate.feff.workflows.eels module

`atomate.feff.workflows.eels.` `get_wf_eels`(absorbing_atom, structure=None, spectrum_type=u'ELNES', edge=u'K', radius=10.0, beam_energy=100, beam_direction=None, collection_angle=1, convergence_angle=1, user_eels_settings=None, user_tag_settings=None, feff_cmd=u'feff', db_file=None, metadata=None, use_primitive=False, feff_input_set=None)

  Returns FEFF ELNES/EXELFS spectroscopy workflow.

  Args:

    absorbing_atom (str): absorbing atom symbol structure (Structure): input structure. If None and mp_id is provided, the corresponding

    > structure will be fetched from the Materials Project db.

    spectrum_type (str): ELNES or EXELFS edge (str): absorption edge. K, L1, L2, L3 radius (float): cluster radius in angstroms. Ignored for reciprocal space calculations beam_energy (float): the incident beam energy in keV beam_direction (list): incident beam direction. Default is none ==> the spectrum will be

    > averaged over all directions.

    collection_angle (float): collection angle in mrad convergence_angle (float): convergence angle in mrad user_eels_settings (dict): override default eels settings. user_tag_settings (dict): override other general feff default tag settings. feff_cmd (str): path to the feff binary db_file (str): path to the db file. metadata (dict): meta data use_primitive (bool): convert the structure to primitive form. This helps to

    > reduce the number of fireworks in the workflow if the absorbing atoms is specified by its atomic symbol.

    feff_input_set (FeffDictSet)

  Returns:
    Workflow

## atomate.feff.workflows.xas module

`atomate.feff.workflows.xas.` `get_wf_xas`(absorbing_atom, structure, spectrum_type=u'XANES', edge=u'K', radius=10.0, feff_input_set=None, feff_cmd=u'feff', db_file=None, metadata=None, user_tag_settings=None, use_primitive=False)

  Returns FEFF XANES/EXAFS spectroscopy workflow.

  Args:
    absorbing_atom (str/int): absorbing atom symbol or site index. If the symbol is given,
      then the returned workflow will have fireworks for each absorbing site with the same symbol.

    structure (Structure): input structure spectrum_type (str): XANES or EXAFS edge (str): absorption edge. Example: K, L1, L2, L3 radius (float): cluster radius in angstroms. Ignored for K space calculations feff_input_set (FeffDictSet): the input set for the FEFF run feff_cmd (str): path to the feff binary db_file (str): path to the db file. metadata (dict): meta data user_tag_settings (dict): override feff default tag settings use_primitive (bool): convert the structure to primitive form. This helps to

    > reduce the number of fireworks in the workflow if the absorbing atom is specified by its atomic symbol.

  Returns:
    Workflow

## Module contents